# Tutorials

1. [Basic walkthrough notebook](notebooks/walkthrough-basic.ipynb)
1. [Compare phase linking algorithms on simulated data](notebooks/simulate-demo.ipynb)
1. [Solving systems of unwrapped interferograms using $L_1$ norm minimzation](notebooks/theory-l1-invert-congruence.ipynb)

<!-- This part of the project documentation will contain step-by-step instructions for learning about generating displacement using Dolphin. -->

<!-- **learning-oriented** approach. You'll learn how to
get started with the code in this project.

**Note:** Expand this section by considering the
following points:

- Help newcomers with getting started
- Teach readers about your library by making them
    write code
- Inspire confidence through examples that work for
    everyone, repeatably
- Give readers an immediate sense of achievement
- Show concrete examples, no abstractions
- Provide the minimum necessary explanation
- Avoid any distractions -->
